Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ARN ¶
type ARN struct {
// The partition that the resource is in.
Partition string
// The service namespace that identifies the product (for example, RAM).
Service string
// The region the resource resides in. Note that the ARNs for some resources do not require a region, so this
// component might be omitted.
Region string
// The ID of the RAM account that owns the resource, without the hyphens. For example, 123456789012. Note that the
// ARNs for some resources don't require an account number, so this component might be omitted.
AccountID string
// The content of this part of the ARN varies by service.
Resource string
}
ARN captures the individual fields of an RAM Resource Name.
Click to show internal directories.
Click to hide internal directories.